## 🎉 1.5.6(20-02-2026)

### ✨ Nuevas características
- Corrección del empaquetado para generar traer los templates
- Implementación de imagenes para los titulos.
- Generación de reportes y Formularios de manera ágil
- Eliminación
- Ajuste a la importación de la fuente al servidor

### 🐛 Correcciones
- Corregido error de alineación en paginación del footer.
- Mejorada compatibilidad con Django 4.2+.
- Corrección a la libreria para forzar la letra en linux (comentarear este componente style.html desde local)
- Inyencción directa de la fuente para evitar problemas con cualquier SO.
- Corrección errores sobre la fuente roboto se deshabilita mientras se corrige el error.

### 📚 Documentación
- Actualizado README con badges y uso de componentes.

### 🧹 Mejoras internas
- Refactorizado builder para mayor escalabilidad.
- Optimizado manejo de estilos CSS.
- Generacion de componentes vacios para la generacion de pdfs oficiales

---

## 🚀 Próxima versión

*(Cambios que están en desarrollo y aún no se han publicado)*

### ✨ Nuevas características
- ...

### 🐛 Correcciones
- ...

### 🧹 Mejoras internas
- ...